ExtensionKey

Trait ExtensionKey 

pub trait ExtensionKey {
    const EXTENSION_KEY: &'static str;
}
Associates a Rust type with its wire-format key in the x402 extensions map.

Types that represent protocol extension data implement this trait to declare the JSON object key under which they are stored and retrieved in ExtensionsJson.

Required items

  • EXTENSION_KEY – A 'static string slice that is the exact key used in the JSON wire format (e.g., "eip2612GasSponsoring").

Required Associated Constants

const EXTENSION_KEY: &'static str

The JSON key under which this extension type is stored in the extensions map of a payment message.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors